# Infrastructure diagrams

## Electric flowchart
```mermaid
flowchart LR

GRID[Grid] --> EPS[EPS EcoFlow River 288Wh]
EPS --> USB[USB Charging for smartphone, etc.]
EPS --> LIGHT[Emergency light]
EPS --> EMERGENCY_AC[Emergency AC outlet for boiler, etc.]
EPS ---> UPS[UPS CyberPower CP375JP 8.5Wh]
UPS --> ROUTER[OpenWrt Router]
UPS --> DESKTOP[Deskstop]
UPS --> MONITOR[Monitor]
```

## Internet flowchart

```mermaid
flowchart TD

    LXD[lxd.home.arpa]
    LXD --> CONTAINERS{"Containers *.benpro.fr"}
    CONTAINERS --> OPENWRT[openwrt.home.arpa]
    OPENWRT --> |Active| WAN[WAN NTT 100Mbps]
    OPENWRT --> |Manual Failover| WWAN["WWAN 5G\nPovo 2.0"]
    WAN --> MULLVAD[Mullvad VPN\nJapan Osaka]
    WWAN --> MULLVAD
    MULLVAD --> CF[Cloudflare Tunnels]
    CF --> INTERNET[Internet]

    MAIL[mail.benpro.fr] --> HETZNER[Hetzner\nFinland]
    HETZNER --> INTERNET


    ORACLE["VM oracle.benpro.fr hosts:\ndns.benpro.fr\nstatus.benpro.fr"] --> ORACLEVM[Oracle OCI\nJapan Tokyo]
    ORACLEVM --> INTERNET

    YOU[Curious visitor] --> INTERNET
```

## VPN port allocation

```mermaid
flowchart LR

    INTERNET[Internet] --> MULLVAD[Mullvad VPN\nvpn.benpro.fr] --> JPTYO{JP-OSA}
    JPTYO --> PORT_56563[Port 56563]
    JPTYO --> PORT_54805[Port 54805]
    PORT_56563 --> LXD[lxd.home.arpa]
    PORT_54805 --> LXD
    LXD --> |Port 56563| GIT[Container git:22]
    LXD --> |Port 54805| CHOWME[Container chownme:22]
```

## Backups flowchart

```mermaid
flowchart TD

    DESKTOP_HOME["chiisai.home.arpa\nJapan"] --> |borg, only homedir| BORGBASEUSA
    DESKTOP_HOME --> |borg, only homedir| BORGDANIEL
    DESKTOP_HOME --> |LVM LVs| HDD_INT[Internal HDD]

    HDD_INT_BACKUP --> |LVM LV| HDD_INT
    HDD_INT --> |rsync| HDD_EXT[External HDD]
    HDD_EXT --> |borg| BORGBASEUSA

    LXD["lxd.home.arpa\nJapan"] --> |lxd export| HDD_INT_BACKUP[hdd-lxd_zfs_backup]
    HDD_INT_BACKUP --> |borg| BORGBASEUSA[borgbase.com\nUSA]
    HDD_INT_BACKUP --> |borg| BORGDANIEL[chown.me\nCanada]

    MAIL[mail.benpro.fr] --> |borg| BORGBASEDE[borgbase.com\nGermany]
    MAIL --> |borg| BORGDANIEL
```

## Syncthing flowchart

```mermaid
flowchart LR

    subgraph Smartphone
    SMARTPHONE[Smartphone] --> SMARTPHONE_FOLDERS{Folders}
    SMARTPHONE_FOLDERS --> SMARTPHONE_FOLDERS_DCIM[DCIM]
    SMARTPHONE_FOLDERS --> SMARTPHONE_FOLDERS_PICTURES[Pictures]
    SMARTPHONE_FOLDERS_DCIM --> SMARTPHONE_FOLDERS_DCIM_CAMERA[Camera]
    SMARTPHONE_FOLDERS_PICTURES --> SMARTPHONE_FOLDERS_PICTURES_ADOBELIGHTROOM[AdobeLightroom]
    SMARTPHONE_FOLDERS --> SMARTPHONE_FOLDERS_DOCUMENTS[Documents]
    SMARTPHONE_FOLDERS_DOCUMENTS --> SMARTPHONE_FOLDERS_DOCUMENTS_KEEPASS[KeePass]
    SMARTPHONE_FOLDERS_DOCUMENTS --> SMARTPHONE_FOLDERS_DOCUMENTS_SCAN[Scan]
    SMARTPHONE_FOLDERS --> SMARTPHONE_FOLDERS_MUSIC[Music]
    SMARTPHONE_FOLDERS_MUSIC --> SMARTPHONE_FOLDERS_MUSIC_FAVOTIRES[Favorites]
    end
    
    subgraph Desktop
    DESKTOP[Desktop] --> DESKTOP_FOLDERS{Folders}
    DESKTOP_FOLDERS --> DESKTOP_FOLDERS_HOME[home]
    DESKTOP_FOLDERS_HOME --> DESKTOP_FOLDERS_HOME_PICTURES["Pictures (MMC)"]
    DESKTOP_FOLDERS_HOME_PICTURES --> DESKTOP_FOLDERS_HOME_PICTURES_SMARTPHONE[Smartphone]
    DESKTOP_FOLDERS_HOME_PICTURES_SMARTPHONE --> DESKTOP_FOLDERS_HOME_PICTURES_SMARTPHONE_CAMERA[Camera]
    DESKTOP_FOLDERS_HOME_PICTURES_SMARTPHONE --> DESKTOP_FOLDERS_HOME_PICTURES_SMARTPHONE_ADOBELIGHTROOM[AdobeLightroom]
    DESKTOP_FOLDERS_HOME_PICTURES -. Manual move .-> DESKTOP_FOLDERS_HOME_PICTURES_GALLERY[gallery.benpro.fr]
    CAMERA{{Camera SD Card}} -. Manual upload .-> ADOBECLOUD[(Adobe Cloud)]
    DESKTOP_FOLDERS_HOME --> DESKTOP_FOLDERS_HOME_DOCUMENTS["Documents (NVME)"]
    DESKTOP_FOLDERS_HOME_DOCUMENTS --> DESKTOP_FOLDERS_HOME_DOCUMENTS_KEEPASS[KeePass]
    DESKTOP_FOLDERS_HOME_DOCUMENTS --> DESKTOP_FOLDERS_HOME_DOCUMENTS_SMARTPHONE[Smartphone]
    DESKTOP_FOLDERS_HOME_DOCUMENTS_SMARTPHONE --> DESKTOP_FOLDERS_HOME_DOCUMENTS_SMARTPHONE_SCAN[Scan]
    DESKTOP_FOLDERS_HOME --> DESKTOP_FOLDERS_HOME_VIDEOS["Videos (HDD)"]
    DESKTOP_FOLDERS_HOME_VIDEOS --> DESKTOP_FOLDERS_HOME_VIDEOS_SHARED[Shared]
    DESKTOP_FOLDERS_HOME --> DESKTOP_FOLDERS_HOME_MUSIC["Music (HDD)"]
    DESKTOP_FOLDERS_HOME_MUSIC --> DESKTOP_FOLDERS_HOME_MUSIC_FAVORITES[Favorites]
    end

    subgraph Tablet
    TABLET[Tablet] --> TABLET_FOLDERS{Folders}
    TABLET_FOLDERS --> TABLET_FOLDERS_MOVIES[Movies]
    TABLET_FOLDERS_MOVIES --> TABLET_FOLDERS_MOVIES_SHARED[Shared]
    end

    subgraph LXD VM
    LXD[LXD] --> LXD_FOLDERS{Volumes}
    LXD_FOLDERS --> LXD_FOLDERS_GALLERY["LXD gallery-originals (HDD)"]
    end

    SMARTPHONE_FOLDERS_DCIM_CAMERA <--> DESKTOP_FOLDERS_HOME_PICTURES_SMARTPHONE_CAMERA
    SMARTPHONE_FOLDERS_PICTURES_ADOBELIGHTROOM <--> DESKTOP_FOLDERS_HOME_PICTURES_SMARTPHONE_ADOBELIGHTROOM
    SMARTPHONE_FOLDERS_DOCUMENTS_SCAN <--> DESKTOP_FOLDERS_HOME_DOCUMENTS_SMARTPHONE_SCAN
    DESKTOP_FOLDERS_HOME_DOCUMENTS_KEEPASS -. Send only .->  SMARTPHONE_FOLDERS_DOCUMENTS_KEEPASS
    DESKTOP_FOLDERS_HOME_VIDEOS_SHARED --> TABLET_FOLDERS_MOVIES_SHARED
    DESKTOP_FOLDERS_HOME_MUSIC_FAVORITES -. Send only .-> SMARTPHONE_FOLDERS_MUSIC_FAVOTIRES
    DESKTOP_FOLDERS_HOME_PICTURES_GALLERY -. Send only .-> LXD_FOLDERS_GALLERY
    ADOBECLOUD --> SMARTPHONE_FOLDERS_PICTURES_ADOBELIGHTROOM
```
